// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package main

import (
	"log"
	"os"

	"gopkg.in/yaml.v2"
)

func main() {
	if len(os.Args) != 2 {
		log.Fatal("Usage: xbus-client-reset-cert <path/to/xbus[-client|ctl].yaml>")
	}
	filename := os.Args[1]

	b, err := os.ReadFile(filename)
	if err != nil {
		log.Fatal(err)
	}

	fi, err := os.Lstat(filename)
	if err != nil {
		log.Fatal(err)
	}

	var data map[string]interface{}
	if err := yaml.Unmarshal(b, &data); err != nil {
		log.Fatal(err)
	}

	delete(data, "tls.certificate")

	if d, ok := data["tls"]; ok {
		if tls, ok := d.(map[interface{}]interface{}); ok {
			delete(tls, "certificate")
		}
	}

	if b, err = yaml.Marshal(data); err != nil {
		log.Fatal(err)
	}

	if err := os.Rename(filename, filename+".old"); err != nil {
		log.Fatal(err)
	}

	if err := os.WriteFile(filename, b, fi.Mode()); err != nil {
		log.Fatal(err)
	}
}
