// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"github.com/spf13/cobra"

	fullenv "xbus.io/xbus/fullenv_tests"
)

var setupCmd = &cobra.Command{
	Use:   "setup",
	Short: "Setup a fullenv directory",
	Run:   xbusFullenvSetup,
}

func xbusFullenvSetup(cmd *cobra.Command, args []string) {
	if len(args) != 1 {
		usage(cmd)
	}

	basename, options, err := loadOptions(cmd, args[0])
	if err != nil {
		return
	}

	options.NoDBLock = true

	env := fullenv.NewFullEnv(basename, options)

	if err := env.Init(); err != nil {
		Logger.Error().Msgf("Could not init env: %s", err)
		return
	}

	env.Close()
}

func init() {
	RootCmd.AddCommand(setupCmd)
}
