// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"github.com/spf13/cobra"
	xbus "xbus.io/go-xbus/v4"
	"xbus.io/go-xbus/v4/api"
)

// accountCmd represents the account command.
var accountCmd = &cobra.Command{
	Use:   "account",
	Short: "Manage accounts that are allowed to connect to Xbus.",
	Long: `This command contains several sub-commands to manage accounts and the
permissions they have within Xbus.

In particular, it is possible from this interface to accept / reject pending
account requests.`,
}

func findAccountID(conn *xbus.Client, identifier string) (api.UUID, error) {
	if id, err := api.UUIDFromString(identifier); err == nil {
		return id, nil
	}
	account, err := conn.AccountFind(identifier)
	return account.GetIDAsUUID(), err
}

func init() {
	RootCmd.AddCommand(accountCmd)
}
