// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"fmt"
	"os"

	"github.com/spf13/cobra"
	"xbus.io/go-xbus/v4/api/control"
)

var accountGetAPIKeyCmd = &cobra.Command{
	Use:   "get-apikey <identifier>",
	Short: "Get the current APIKey of an account",
	Run: func(cmd *cobra.Command, args []string) {
		if len(args) != 1 {
			if err := cmd.Usage(); err != nil {
				Logger.Error().Msgf("Failed to print usage: %s", err)
			}
			os.Exit(1)
		}
		os.Exit(accountGetAPIKey(args[0]))
	},
}

func accountGetAPIKey(identifier string) int {
	conn, err := GetClient(false)
	if err != nil {
		Logger.Error().Msgf("Cannot connect to the NATS server: %s", err)
		return 1
	}

	account, err := conn.AccountFind(identifier)
	if err != nil {
		Logger.Error().Msgf("Could not find account %s: %s", identifier, err)
		return 1
	}

	account, err = conn.Control.Account.GetAPIKey(
		&control.AccountIDRequest{AccountID: account.ID})
	if err != nil {
		Logger.Error().Msgf("Error getting the account apikey: %s", err)
		return 1
	}

	fmt.Printf("API Key:\n%s\n", account.ApiKey)

	return 0
}

func init() {
	accountCmd.AddCommand(accountGetAPIKeyCmd)
}
