// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"fmt"

	"github.com/spf13/cobra"
	"xbus.io/go-xbus/v4/api"
)

// actorCmd represents the actor command
var actorCmd = &cobra.Command{
	Use:   "actor",
	Short: "Actor handling",
	Long:  ``,
}

func fmtActor(prefix string, actor *api.Actor, accountList []*api.Account) string {
	var (
		accountsByUUID = make(map[api.UUID]*api.Account)
	)
	for _, account := range accountList {
		accountsByUUID[account.GetIDAsUUID()] = account
	}
	state := "offline"
	if actor.Online {
		state = "online"
		if actor.Unresponsive {
			state += fmt.Sprintf(", unresponsive (last seen: %v)", actor.LastSeen)
		}
	}
	s := fmt.Sprintf(
		"%sID: %s (%s)\n%sName: %s\n%sKind: %s\n%sRole: %s\n%sAccount: %s\n",
		prefix, actor.ID, state,
		prefix, actor.Name,
		prefix, actor.Kind,
		prefix, actor.Roles[0],
		prefix, accountsByUUID[actor.GetAccountIDAsUUID()].Name,
	)
	return s
}

func init() {
	RootCmd.AddCommand(actorCmd)

	flags := actorCmd.PersistentFlags()
	flags.String("id", "", "Actor's ID")
	flags.String("name", "", "Actor's name")
	flags.String("role", "", "Actor's role")
	flags.String("type", "", "Actor's type (emitter, consumer)")
}
