// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"errors"
	"fmt"
	"os"

	"github.com/spf13/cobra"
	xbus "xbus.io/go-xbus/v4"
)

var actorConfigCmd = &cobra.Command{
	Use:   "config",
	Short: "Manipulate the actor configuration entries",
	Long:  "Manipulate the actor configuration entries",
	Run: func(cmd *cobra.Command, args []string) {
		// Default action, display the config entries

		conn, err := GetClient(false)
		if err != nil {
			Logger.Error().Msgf("Cannot connect to the NATS server: %s", err)
			os.Exit(1)
		}
		var identifier string
		if v := cmd.Flag("id"); v.Changed {
			identifier = v.Value.String()
		} else if v := cmd.Flag("name"); v.Changed {
			identifier = v.Value.String()
		} else if len(args) == 1 {
			identifier = args[0]
		} else {
			usage(cmd)
		}

		actor, err := conn.ActorFind(identifier)
		if err != nil {
			if errors.Is(err, xbus.ErrNotFound) {
				Logger.Error().Msgf("actor not found")
			} else {
				Logger.Error().Msgf("could not find actor: %s", err)
			}
			os.Exit(1)
		}

		fmt.Println("Actor", actor.Name, "configuration:")
		if len(actor.Config) == 0 {
			fmt.Println("    <none>")
		} else {
			for _, entry := range actor.Config {
				fmt.Printf("%s\t= %s\n", entry.Key, entry.Value)
			}
		}
	},
}

func init() {
	actorCmd.AddCommand(actorConfigCmd)
}
