// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"fmt"

	"github.com/spf13/cobra"
	"xbus.io/go-xbus/v4/api"
)

// actorCreateCmd represents the list command
var actorCreateCmd = &cobra.Command{
	Use:   "create",
	Short: "Create a new actor",
	Long:  ``,
	Run: func(cmd *cobra.Command, args []string) {
		c, err := GetClient(false)
		if err != nil {
			return
		}
		id, _ := api.UUIDFromString(cmd.Flag("id").Value.String())
		actor := api.Actor{
			ID:    id.ToBytes(),
			Name:  cmd.Flag("name").Value.String(),
			Roles: []string{cmd.Flag("type").Value.String()},
		}
		err = actor.Kind.UnmarshalText([]byte(cmd.Flag("type").Value.String()))
		if err != nil {
			Logger.Error().Msgf("Error parsing type. Got %s", err)
			return
		}
		created, err := c.ActorCreate([]*api.Actor{&actor})
		if err != nil {
			Logger.Error().Msgf("Error: %s", err)
			return
		}
		if len(created) == 0 {
			fmt.Println("No actor created")
		} else {
			accounts, err := c.AccountList()
			if err != nil {
				Logger.Error().Msgf("Could not load the accounts: %s", err)
			}
			for _, actor := range created {
				fmt.Println(fmtActor("", actor, accounts))
			}
		}
	},
}

func init() {
	actorCmd.AddCommand(actorCreateCmd)
}
