// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"fmt"
	"log"
	"strings"
)

var (
	okayResponses  = []string{"y", "yes"}
	nokayResponses = []string{"n", "no"}
)

// containsString returns true iff slice contains element
func containsString(slice []string, element string) bool {
	for _, s := range slice {
		if s == element {
			return true
		}
	}
	return false
}

// askForConfirmation uses Scanln to parse user input. A user must type in "yes" or "no" and
// then press enter. It has fuzzy matching, so "y", "Y", "yes", "YES", and "Yes" all count as
// confirmations. If the input is not recognized, it will ask again. The function does not return
// until it gets a valid response from the user. Typically, you should use fmt to print out a question
// before calling askForConfirmation. E.g. fmt.Println("WARNING: Are you sure? (yes/no)")
func askForConfirmation(prompt string) bool {
	for {
		fmt.Print(prompt + " (yes/NO): ")
		var response string
		_, err := fmt.Scanln(&response)
		if err != nil {
			if err.Error() == "unexpected newline" {
				return false
			}
			log.Fatal(err)
		}
		response = strings.ToLower(response)

		if containsString(okayResponses, response) {
			return true
		} else if containsString(nokayResponses, response) {
			return false
		}
	}
}
