// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"context"
	"fmt"
	"os"
	"time"

	"github.com/spf13/cobra"
)

var logsPurgeCmd = &cobra.Command{
	Use:   "purge",
	Short: "Purge logs",
	Run: func(cmd *cobra.Command, args []string) {
		c, err := GetClient(false)
		if err != nil {
			return
		}
		duration, err := cmd.Flags().GetDuration("older")
		if err != nil {
			return
		}
		if duration <= 0 {
			Logger.Error().Msgf("Please specify a positive and non-null age")
			return
		}
		before := time.Now().Add(-duration)
		Logger.Info().Msgf("Will purged logs before %s", before)
		ctx, _ := contextCancelOnSignal(
			context.Background(), os.Interrupt,
		)
		fmt.Print("\nPurge: ")
		count, err := c.LogsPurge(ctx, before)
		if err != nil {
			Logger.Error().Msgf("Error: %s", err)
			return
		}
		Logger.Info().Msgf("Purged %d log entries", count)
	},
}

func init() {
	logsCmd.AddCommand(logsPurgeCmd)

	flags := logsPurgeCmd.Flags()
	flags.Duration("older", 0, "Select logs older that the passed duration")
}
