// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"os"

	"github.com/spf13/cobra"
	"xbus.io/go-xbus/v4/api"
)

var pipelineStatusCmd = &cobra.Command{
	Use:   "status <name or id> [version] [--active|--inactive]",
	Short: "Change the status of a pipeline version",
	Run: func(cmd *cobra.Command, args []string) {
		if len(args) < 1 || len(args) > 2 {
			usage(cmd)
		}
		var (
			identifier = args[0]
			version    string
		)
		if len(args) == 2 {
			version = args[1]
		}
		var status api.PipelineInfo_Status
		if cmd.Flag("active").Value.String() == "true" {
			status = api.PipelineInfo_ACTIVE
		} else if cmd.Flag("inactive").Value.String() == "true" {
			status = api.PipelineInfo_INACTIVE
		}
		if err := pipelineStatus(identifier, version, status); err != nil {
			Logger.Error().Msgf("Error setting pipeline status: %s", err)
			os.Exit(-1)
		}
	},
}

func pipelineStatus(identifier, version string, status api.PipelineInfo_Status) error {
	c, err := GetClient(false)
	if err != nil {
		return err
	}

	info := pipelineInfo(identifier, version)
	info.Status = status

	info, err = c.PipelineSetStatus(info)
	if err != nil {
		return err
	}
	Logger.Info().Msgf("%s-%s status changed to %s", info.Name, info.Version, info.Status)
	return nil
}

func init() {
	pipelineCmd.AddCommand(pipelineStatusCmd)

	pipelineStatusCmd.Flags().Bool("active", false, "Activate the pipeline")
	pipelineStatusCmd.Flags().Bool("inactive", false, "Deactivate the pipeline")
}
