// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package cmd

import (
	"time"

	"github.com/spf13/cobra"

	"xbus.io/xbus/utils"
)

const (
	flagExpire     = "expire"
	flagExpireHelp = "A date (YYYY-MM-DD) or duration (in y, m or d) for expiration"

	flagHostDefs     = "host-defs"
	flagHostDefsHelp = `A comma separated list of hostname and ip addresses
that may be used to contact the server.
Example: "xbus.mycompany.org,10.0.0.122,128.0.0.1"`
)

func getExpire(cmd *cobra.Command, flag string) (time.Time, error) {
	expireString, err := cmd.Flags().GetString(flag)
	if err != nil {
		return time.Time{}, err
	}
	return utils.ParseDateOrDuration(expireString)
}

// certCmd represents the certificate command.
var certCmd = &cobra.Command{
	Use:              "cert",
	Short:            "Manage certificates used by this program.",
	Long:             "Manage certificates used by this program.",
	PersistentPreRun: preRunCheckCertCertDir,
}

func init() {
	RootCmd.AddCommand(certCmd)
}
