// Copyright (c) 2016-2023 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package migration

//go:generate go-bindata -pkg migration -prefix scripts scripts

import (
	"github.com/golang-migrate/migrate/v4"
	"github.com/golang-migrate/migrate/v4/database/postgres"
	"github.com/golang-migrate/migrate/v4/source"
	bindata "github.com/golang-migrate/migrate/v4/source/go_bindata"
	"github.com/orus-io/yago"
)

// New returns a migrate instance for migrating the given database
func New(db *yago.DB) (*migrate.Migrate, source.Driver, error) {
	// wrap assets into Resource
	s := bindata.Resource(AssetNames(), Asset)

	source, err := bindata.WithInstance(s)
	if err != nil {
		return nil, nil, err
	}
	database, err := postgres.WithInstance(db.Engine.DB().DB, &postgres.Config{})
	if err != nil {
		return nil, nil, err
	}
	m, err := migrate.NewWithInstance(
		"go-bindata", source,
		"postgres", database,
	)
	return m, source, err
}
