// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package storage

import (
	jsoniter "github.com/json-iterator/go"
	"xbus.io/go-xbus/v4/api"
	"xbus.io/go-xbus/v4/utils"
)

func (p *Pipeline) MarshalJSONStream(stream *jsoniter.Stream) {
	obj := utils.NewJSONStreamObject(stream)

	if !p.GetIDAsUUID().IsZero() {
		obj.Field("id")
		api.JSONStreamWriteUUID(stream, p.ID)
	}
	if p.Name != "" {
		obj.String("name", p.Name)
	}
	if p.Version != "" {
		obj.String("version", p.Version)
	}
	obj.String("status", p.Status.String())
	nodes := obj.Array("nodes")
	for _, node := range p.Graph.Nodes {
		nodes.Val(node)
	}
	nodes.End()
	edges := obj.Array("edges")
	for _, edge := range p.Graph.Edges {
		edges.String(edge.String())
	}
	edges.End()
	obj.End()
}
