// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package storage

import (
	"context"
	"errors"

	"xbus.io/go-xbus/v4/api"
)

// ErrInvalidPipelineStatus is returned when the pipeline status does not
// allow the operation
var ErrInvalidPipelineStatus = errors.New("Invalid Pipeline Status")

func NewPipeline() Pipeline {
	return Pipeline{
		PipelineInfo: &api.PipelineInfo{},
	}
}

// Pipeline defines how an envelope should be processed
type Pipeline struct {
	*api.PipelineInfo
	Graph Graph
}

// PipelineStorage handle Pipeline persistence
type PipelineStorage interface {
	Load(context.Context, api.UUID) (Pipeline, bool)
	Save(context.Context, Pipeline) (api.UUID, error)
	SetStatus(context.Context, api.UUID, api.PipelineInfo_Status) error
	LoadActivePipeline(context.Context) []Pipeline
	Query(ctx context.Context, name, version string, activeOnly bool) []Pipeline
}
