// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package model

import (
	"fmt"

	"github.com/orus-io/qb"
	"github.com/orus-io/yago"
	"github.com/rs/zerolog"
)

// NewDB initialize a Model and a DB
func NewDB(driver string, params string, maxConns int, logger zerolog.Logger, logFlags qb.LogFlags) (*Model, *yago.DB, error) {
	model := NewModel()
	engine, err := qb.New(driver, params)
	if err != nil {
		return nil, nil, fmt.Errorf("DB engine initialization failed: %w", err)
	}
	engine.SetDialect(qb.NewDialect(driver))
	engine.SetLogger(&QBLogger{logger: logger})
	engine.SetLogFlags(logFlags)
	engine.DB().SetMaxOpenConns(maxConns)

	db := yago.New(model.Meta, engine)

	return model, db, nil
}
