// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package utils

import (
	"context"
	"fmt"
	"os"
	"os/signal"
)

func ContextWithSignals(ctx context.Context, sig ...os.Signal) context.Context {
	ctx, cancel := context.WithCancelCause(ctx)
	signals := make(chan os.Signal, 1)
	signal.Notify(signals, sig...)
	go func() {
		select {
		case sig := <-signals:
			cancel(fmt.Errorf("Caught signal: %s", sig))
		case <-ctx.Done():
			return
		}
	}()
	return ctx
}
