// Copyright (c) 2016-2024 CloudCrane. All rights reserved.
//
// This work is licensed under the MIT License.
// See the LICENSE file in the project root for more information.

package utils_test

import (
	"strings"
	"testing"

	"github.com/stretchr/testify/require"

	"xbus.io/xbus/utils"
)

func TestJson2Yaml(t *testing.T) {
	for _, tt := range []struct {
		name string
		json string
		yaml string
	}{
		{"basics",
			`["1", 2, false, null, "multi-\nline\nstring",
			{"name":"test", "age":55, "address": {"street": "rue des petits chats", "city": "Londres"}, "phone": [ "12345", "67890" ]}]`,
			`- "1"
- 2
- false
- null
- |+
    multi-
    line
    string
- name: "test"
  age: 55
  address:
    street: "rue des petits chats"
    city: "Londres"
  phone:
  - "12345"
  - "67890"
`,
		},
	} {
		t.Run(tt.name, func(t *testing.T) {
			var w strings.Builder
			require.NoError(t, utils.JSON2YAML(&w, strings.NewReader(tt.json)))
			require.Equal(t, tt.yaml, w.String())
		})
	}
}
