package demo

import (
	"context"
	"fmt"
	"time"

	xbus "xbus.io/go-xbus/v4"
	"xbus.io/go-xbus/v4/envelope"
)

// NewCounterEmitter is a CounterEmitter factory
func NewCounterEmitter(actor *xbus.Actor, settings xbus.Settings) (xbus.ActorService, error) {
	return &CounterEmitter{
		actor:    actor,
		interval: settings.MustIntD("interval", 1),
		offset:   settings.MustIntD("offset", 0),
		limit:    settings.MustIntD("limit", 100),
		count:    settings.MustIntD("offset", 0),
	}, nil
}

// CounterEmitter is an emitter that counts from
type CounterEmitter struct {
	actor    *xbus.Actor
	interval int
	offset   int
	limit    int
	count    int
	quit     chan bool
}

// Startup starts a routine that send all the counter values
func (c *CounterEmitter) Startup() error {
	if c.count > c.limit {
		return nil
	}
	c.quit = make(chan bool)
	go func() {
		for {
			select {
			case <-time.After(time.Duration(c.interval) * time.Millisecond):
				message := fmt.Sprintf("%d", c.count)
				if _, err := c.actor.Emit(
					context.Background(),
					envelope.MustNewEnvelope(
						envelope.MustNewTextMessage("demo.count", message)),
				); err != nil {
					c.actor.Log.Err(err).Msg("send failed")
				}
				c.actor.Log.Info().Msgf("sent %d", c.count)
				c.count++
				if c.count > c.limit {
					return
				}
			case <-c.quit:
				return
			}
		}
	}()
	return nil
}

// Shutdown stops the ticker
func (c *CounterEmitter) Shutdown() error {
	close(c.quit)
	return nil
}

func init() {
	xbus.RegisterActorService("demo.counter", NewCounterEmitter)
}
