package utils

import (
	"context"
	"os"
	"os/signal"
)

// CtxWithSignal returns a context that will be canceled by the given signals
func CtxWithSignal(ctx context.Context, sig ...os.Signal) (context.Context, func()) {
	// trap Ctrl+C and call cancel on the context
	ctx, cancel := context.WithCancel(ctx)

	c := make(chan os.Signal, 1)

	signal.Notify(c, sig...)

	go func() {
		select {
		case <-c:
			cancel()
		case <-ctx.Done():
		}
	}()

	return ctx, func() {
		signal.Stop(c)
		cancel()
	}
}
