package utils

import (
	"io"

	jsoniter "github.com/json-iterator/go"
)

// JSONIterUnmarshaler is a type that can unmarshal itself from a jsoniter.Iterator
type JSONIterUnmarshaler interface {
	UnmarshalJSONIter(*jsoniter.Iterator)
}

// JSONIterReadPointer unmarshals a JSONIterUnmarshaler type to a new instance
func JSONIterReadPointer[P interface {
	*T
	JSONIterUnmarshaler
}, T any](iter *jsoniter.Iterator) *T {
	t := new(T)
	P(t).UnmarshalJSONIter(iter)
	if iter.Error != nil {
		return nil
	}
	return t
}

func JSONIterReadArray[P interface {
	*T
	JSONIterUnmarshaler
}, T any](i *jsoniter.Iterator) []*T {
	var list []*T
	i.ReadArrayCB(func(i *jsoniter.Iterator) bool {
		t := new(T)
		P(t).UnmarshalJSONIter(i)
		if i.Error != nil {
			return false
		}
		list = append(list, t)
		return true
	})
	return list
}

func DecodeJSON[T JSONIterUnmarshaler](r io.Reader, value T) error {
	data, err := io.ReadAll(r)
	if err != nil {
		return err
	}
	iter := jsoniter.ConfigDefault.BorrowIterator(data)
	defer jsoniter.ConfigDefault.ReturnIterator(iter)
	value.UnmarshalJSONIter(iter)
	return iter.Error
}

func UnmarshalJSON[T JSONIterUnmarshaler](data []byte, value T) error {
	iter := jsoniter.ConfigDefault.BorrowIterator(data)
	defer jsoniter.ConfigDefault.ReturnIterator(iter)
	value.UnmarshalJSONIter(iter)
	return iter.Error
}
